@@ -1,8 +1,6 @@
-from __future__ import absolute_import, print_function
-
 import sys
 
-from popcon import package
+from popcon import packages
 
 
 def main():
@@ -10,7 +8,7 @@ def main():
         raise RuntimeError('No package name given')
     pkg = sys.argv[1]
     print(pkg)
-    print(package(pkg))
+    print(packages([pkg]))
 
 
 if __name__ == '__main__':
